@@ -28,7 +28,11 @@ func installationCancelledError(shellName string, script string) *core.CliError
 
 func installationNotFound(shellName string, location string, script string) *core.CliError {
 	return &core.CliError{
-		Err:  fmt.Errorf("cannot find where to install autocomplete script (tried %s)", location),
-		Hint: fmt.Sprintf("You can add this line: `%s` in your %s configuration file", script, shellName),
+		Err: fmt.Errorf("cannot find where to install autocomplete script (tried %s)", location),
+		Hint: fmt.Sprintf(
+			"You can add this line: `%s` in your %s configuration file",
+			script,
+			shellName,
+		),
 	}
 }
