@@ -7,9 +7,16 @@ import (
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/baremetal/v1"
 	baremetalSDK "github.com/scaleway/scaleway-sdk-go/api/baremetal/v1"
+	"github.com/scaleway/scaleway-sdk-go/scw"
 	"github.com/stretchr/testify/assert"
 )
 
+var (
+	offerNameNVME = getenv("OFFER_NAME_NVME", "EM-I215E-NVME")
+	offerNameSATA = getenv("OFFER_NAME_SATA", "EM-B111X-SATA")
+	zone          = getenv("zone", "fr-par-2")
+)
+
 // All test below should succeed to create an instance.
 func Test_CreateServer(t *testing.T) {
 	// Simple use cases
@@ -19,8 +26,8 @@ func Test_CreateServer(t *testing.T) {
 			BeforeFunc: func(ctx *core.BeforeFuncCtx) error {
 				api := baremetalSDK.NewAPI(ctx.Client)
 				server, _ := api.GetOfferByName(&baremetalSDK.GetOfferByNameRequest{
-					OfferName: offerName,
-					Zone:      region,
+					OfferName: offerNameNVME,
+					Zone:      scw.Zone(zone),
 				})
 				if server.Stock != baremetalSDK.OfferStockAvailable {
 					return errors.New("offer out of stock")
@@ -28,13 +35,13 @@ func Test_CreateServer(t *testing.T) {
 
 				return nil
 			},
-			Cmd: "scw baremetal server create zone=" + region + " type=" + offerName + " -w",
+			Cmd: "scw baremetal server create zone=" + zone + " type=" + offerNameNVME + " -w",
 			Check: core.TestCheckCombine(
 				core.TestCheckGolden(),
 				core.TestCheckExitCode(0),
 			),
 			AfterFunc: core.ExecAfterCmd(
-				"scw baremetal server delete {{ .CmdResult.ID }} zone=" + region,
+				"scw baremetal server delete {{ .CmdResult.ID }} zone=" + zone,
 			),
 		},
 		))
@@ -44,8 +51,8 @@ func Test_CreateServer(t *testing.T) {
 			BeforeFunc: func(ctx *core.BeforeFuncCtx) error {
 				api := baremetalSDK.NewAPI(ctx.Client)
 				server, _ := api.GetOfferByName(&baremetalSDK.GetOfferByNameRequest{
-					OfferName: offerName,
-					Zone:      region,
+					OfferName: offerNameNVME,
+					Zone:      scw.Zone(zone),
 				})
 				if server.Stock != baremetalSDK.OfferStockAvailable {
 					return errors.New("offer out of stock")
@@ -53,7 +60,7 @@ func Test_CreateServer(t *testing.T) {
 
 				return nil
 			},
-			Cmd: "scw baremetal server create name=test-create-server-with-name zone=" + region + " type=" + offerName + " -w",
+			Cmd: "scw baremetal server create name=test-create-server-with-name zone=" + zone + " type=" + offerNameNVME + " -w",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
@@ -66,7 +73,7 @@ func Test_CreateServer(t *testing.T) {
 				core.TestCheckExitCode(0),
 			),
 			AfterFunc: core.ExecAfterCmd(
-				"scw baremetal server delete {{ .CmdResult.ID }} zone=" + region,
+				"scw baremetal server delete {{ .CmdResult.ID }} zone=" + zone,
 			),
 		}))
 
@@ -75,8 +82,8 @@ func Test_CreateServer(t *testing.T) {
 			BeforeFunc: func(ctx *core.BeforeFuncCtx) error {
 				api := baremetalSDK.NewAPI(ctx.Client)
 				server, _ := api.GetOfferByName(&baremetalSDK.GetOfferByNameRequest{
-					OfferName: offerName,
-					Zone:      region,
+					OfferName: offerNameNVME,
+					Zone:      scw.Zone(zone),
 				})
 				if server.Stock != baremetalSDK.OfferStockAvailable {
 					return errors.New("offer out of stock")
@@ -84,7 +91,7 @@ func Test_CreateServer(t *testing.T) {
 
 				return nil
 			},
-			Cmd: "scw baremetal server create tags.0=prod tags.1=blue zone=" + region + " type=" + offerName + " -w",
+			Cmd: "scw baremetal server create tags.0=prod tags.1=blue zone=" + zone + " type=" + offerNameNVME + " -w",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
@@ -94,7 +101,7 @@ func Test_CreateServer(t *testing.T) {
 				core.TestCheckExitCode(0),
 			),
 			AfterFunc: core.ExecAfterCmd(
-				"scw baremetal server delete {{ .CmdResult.ID }} zone=" + region,
+				"scw baremetal server delete {{ .CmdResult.ID }} zone=" + zone,
 			),
 		}))
 	})
