@@ -8,6 +8,7 @@ import (
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/baremetal/v1"
 	iam "github.com/scaleway/scaleway-cli/v2/internal/namespaces/iam/v1alpha1"
 	baremetalSDK "github.com/scaleway/scaleway-sdk-go/api/baremetal/v1"
+	"github.com/scaleway/scaleway-sdk-go/scw"
 )
 
 func Test_InstallServer(t *testing.T) {
@@ -24,8 +25,8 @@ func Test_InstallServer(t *testing.T) {
 				func(ctx *core.BeforeFuncCtx) error {
 					api := baremetalSDK.NewAPI(ctx.Client)
 					server, _ := api.GetOfferByName(&baremetalSDK.GetOfferByNameRequest{
-						OfferName: offerName,
-						Zone:      region,
+						OfferName: offerNameNVME,
+						Zone:      scw.Zone(zone),
 					})
 					if server.Stock != baremetalSDK.OfferStockAvailable {
 						err := errors.New("offer out of stock")
@@ -36,10 +37,10 @@ func Test_InstallServer(t *testing.T) {
 					return nil
 				},
 				addSSH("key", sshKey),
-				createServerAndWait("Server"),
+				createServerAndWait(),
 			),
 			Commands: cmds,
-			Cmd:      "scw baremetal server install {{ .Server.ID }} zone=" + region + " hostname=test-install-server ssh-key-ids.0={{ .key.ID }} os-id=" + osID + " -w",
+			Cmd:      "scw baremetal server install {{ .Server.ID }} zone=" + zone + " hostname=test-install-server ssh-key-ids.0={{ .key.ID }} os-id=" + osID + " -w",
 			Check: core.TestCheckCombine(
 				core.TestCheckGolden(),
 				core.TestCheckExitCode(0),
@@ -56,8 +57,8 @@ func Test_InstallServer(t *testing.T) {
 				func(ctx *core.BeforeFuncCtx) error {
 					api := baremetalSDK.NewAPI(ctx.Client)
 					server, _ := api.GetOfferByName(&baremetalSDK.GetOfferByNameRequest{
-						OfferName: offerName,
-						Zone:      region,
+						OfferName: offerNameNVME,
+						Zone:      scw.Zone(zone),
 					})
 					if server.Stock != baremetalSDK.OfferStockAvailable {
 						return errors.New("offer out of stock")
@@ -66,9 +67,9 @@ func Test_InstallServer(t *testing.T) {
 					return nil
 				},
 				addSSH("key", sshKey),
-				createServerAndWait("Server"),
+				createServerAndWait(),
 			),
-			Cmd: "scw baremetal server install {{ .Server.ID }} zone=" + region + " hostname=test-install-server all-ssh-keys=true os-id=" + osID + " -w",
+			Cmd: "scw baremetal server install {{ .Server.ID }} zone=" + zone + " hostname=test-install-server all-ssh-keys=true os-id=" + osID + " -w",
 			Check: core.TestCheckCombine(
 				core.TestCheckGolden(),
 				core.TestCheckExitCode(0),
