@@ -2,28 +2,31 @@ package baremetal_test
 
 import (
 	"fmt"
+	"os"
 
 	"github.com/scaleway/scaleway-cli/v2/core"
 )
 
+func getenv(key, fallback string) string {
+	value := os.Getenv(key)
+	if len(value) == 0 {
+		return fallback
+	}
+
+	return value
+}
+
 // createServerAndWait creates a baremetal instance
 // register it in the context Meta at metaKey.
-func createServerAndWait(metaKey string) core.BeforeFunc {
+func createServerAndWait() core.BeforeFunc {
 	return core.ExecStoreBeforeCmd(
-		metaKey,
-		"scw baremetal server create zone="+region+" type="+offerName+" -w",
+		"Server",
+		"scw baremetal server create type="+offerNameNVME+" zone="+zone+" -w",
 	)
 }
 
-func createServerAndWaitDefault(metaKey string) core.BeforeFunc {
-	return core.ExecStoreBeforeCmd(metaKey, "scw baremetal server create type="+offerName+" -w")
-}
-
-func createServer(metaKey string, offerType string) core.BeforeFunc {
-	return core.ExecStoreBeforeCmd(
-		metaKey,
-		"scw baremetal server create zone="+region+" type="+offerType,
-	)
+func createServer(metaKey string, offer string) core.BeforeFunc {
+	return core.ExecStoreBeforeCmd(metaKey, "scw baremetal server create zone="+zone+" type="+offer)
 }
 
 // deleteServer deletes a server
@@ -32,14 +35,10 @@ func createServer(metaKey string, offerType string) core.BeforeFunc {
 //nolint:unparam
 func deleteServer(metaKey string) core.AfterFunc {
 	return core.ExecAfterCmd(
-		fmt.Sprintf("scw baremetal server delete zone="+region+" {{ .%s.ID }}", metaKey),
+		fmt.Sprintf("scw baremetal server delete {{ .%s.ID }} zone=%s", metaKey, zone),
 	)
 }
 
-func deleteServerDefault(metaKey string) core.AfterFunc {
-	return core.ExecAfterCmd(fmt.Sprintf("scw baremetal server delete {{ .%s.ID }}", metaKey))
-}
-
 // add an ssh key with a given meta key
 func addSSH(metaKey string, key string) core.BeforeFunc {
 	return func(ctx *core.BeforeFuncCtx) error {
