@@ -314,12 +314,19 @@ func securityGroupDeleteBuilder(c *core.Command) *core.Command {
 				}
 
 				// Create detail message.
-				hint := "Attach all these instances to another security-group before deleting this one:"
+				var hintBuilder strings.Builder
+				hintBuilder.WriteString(
+					"Attach all these instances to another security-group before deleting this one:",
+				)
 				for _, s := range sg.SecurityGroup.Servers {
-					hint += "\nscw instance server update " + s.ID + " security-group.id=$NEW_SECURITY_GROUP_ID"
+					fmt.Fprintf(
+						&hintBuilder,
+						"\nscw instance server update %s security-group.id=$NEW_SECURITY_GROUP_ID",
+						s.ID,
+					)
 				}
 
-				newError.Hint = hint
+				newError.Hint = hintBuilder.String()
 
 				return nil, newError
 			}
