@@ -440,15 +440,76 @@ func instanceGetBuilder(c *core.Command) *core.Command {
 	return c
 }
 
+func instanceUpgradeInterceptor(
+	ctx context.Context,
+	argsI any,
+	runner core.CommandRunner,
+) (any, error) {
+	req := argsI.(*rdbSDK.UpgradeInstanceRequest)
+	api := rdbSDK.NewAPI(core.ExtractClient(ctx))
+
+	instance, err := api.GetInstance(&rdbSDK.GetInstanceRequest{
+		Region:     req.Region,
+		InstanceID: req.InstanceID,
+	})
+	if err != nil {
+		return nil, err
+	}
+
+	if !needsUpgrade(req, instance) {
+		return &core.SuccessResult{Message: "Nothing to do!"}, nil
+	}
+
+	return runner(ctx, argsI)
+}
+
+func needsUpgrade(req *rdbSDK.UpgradeInstanceRequest, instance *rdbSDK.Instance) bool {
+	if req.NodeType != nil && *req.NodeType != "" {
+		if !strings.EqualFold(instance.NodeType, *req.NodeType) {
+			return true
+		}
+	}
+
+	if req.EnableHa != nil && *req.EnableHa && !instance.IsHaCluster {
+		return true
+	}
+
+	if instance.Volume != nil {
+		if req.VolumeType != nil && *req.VolumeType != instance.Volume.Type {
+			return true
+		}
+		if req.VolumeSize != nil && *req.VolumeSize > uint64(instance.Volume.Size) {
+			return true
+		}
+	}
+
+	if req.UpgradableVersionID != nil && *req.UpgradableVersionID != "" {
+		return true
+	}
+
+	if req.MajorUpgradeWorkflow != nil && req.MajorUpgradeWorkflow.UpgradableVersionID != "" {
+		return true
+	}
+
+	return false
+}
+
 func instanceUpgradeBuilder(c *core.Command) *core.Command {
 	c.ArgSpecs.GetByName("node-type").AutoCompleteFunc = autoCompleteNodeType
 
+	c.Interceptor = instanceUpgradeInterceptor
+
 	c.WaitFunc = func(ctx context.Context, _, respI any) (any, error) {
+		if _, ok := respI.(*core.SuccessResult); ok {
+			return respI, nil
+		}
+
+		instance := respI.(*rdbSDK.Instance)
 		api := rdbSDK.NewAPI(core.ExtractClient(ctx))
 
 		return api.WaitForInstance(&rdbSDK.WaitForInstanceRequest{
-			InstanceID:    respI.(*rdbSDK.Instance).ID,
-			Region:        respI.(*rdbSDK.Instance).Region,
+			InstanceID:    instance.ID,
+			Region:        instance.Region,
 			Timeout:       scw.TimeDurationPtr(instanceActionTimeout),
 			RetryInterval: core.DefaultRetryInterval,
 		})
@@ -710,11 +771,15 @@ const (
 	PostgreSQL     = engineFamily("PostgreSQL")
 	MySQL          = engineFamily("MySQL")
 	postgreSQLHint = `
-psql supports password file to avoid typing your password manually.
+psql supports password file (.pgpass) to avoid typing your password manually.
+Create ~/.pgpass (Linux/macOS) or %APPDATA%\postgresql\pgpass.conf (Windows) with:
+  hostname:port:database:username:password
 Learn more at: https://www.postgresql.org/docs/current/libpq-pgpass.html`
 	mySQLHint = `
-mysql supports loading your password from a file to avoid typing them manually.
-Learn more at: https://dev.mysql.com/doc/refman/8.0/en/option-files.html`
+mysql supports mysql_config_editor for secure password storage.
+Use: mysql_config_editor set --login-path=scw --host=HOST --user=USER --password
+Or create ~/.mylogin.cnf with connection credentials.
+Learn more at: https://dev.mysql.com/doc/refman/8.0/en/mysql-config-editor.html`
 )
 
 func passwordFileExist(ctx context.Context, family engineFamily) bool {
