@@ -3,7 +3,7 @@ package test_test
 import (
 	"testing"
 
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	test "github.com/scaleway/scaleway-cli/v2/internal/namespaces/test/custom"
 )
 
