@@ -1,7 +1,7 @@
 package test
 
 import (
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 )
 
 func GetCommands() *core.Commands {
